/*!
 * clipboard.js v1.2.0
 * https://clipboardjs.com/
 *
 * Licensed MIT © Zeno Rocha
 */
(function webpackUniversalModuleDefinition(root, factory) {
	if(typeof exports === 'object' && typeof module === 'object')
		module.exports = factory();
	else if(typeof define === 'function' && define.amd)
		define([], factory);
	else if(typeof exports === 'object')
		exports["ClipboardJS"] = factory();
	else
		root["ClipboardJS"] = factory();
})(this, function() {
return /******/ (function() { // webpackBootstrap
/******/ 	"use strict";
/******/ 	// The require scope
/******/ 	var __webpack_require__ = {};
/******/ 	
/************************************************************************/
/******/ 	/* webpack/runtime/define property getters */
/******/ 	!function() {
/******/ 		// define getter functions for harmony exports
/******/ 		__webpack_require__.d = function(exports, definition) {
/******/ 			for(var key in definition) {
/******/ 				if(__webpack_require__.o(definition, key) && !__webpack_require__.o(exports, key)) {
/******/ 					Object.defineProperty(exports, key, { enumerable: true, get: definition[key] });
/******/ 				}
/******/ 			}
/******/ 		};
/******/ 	}();
/******/ 	
/******/ 	/* webpack/runtime/hasOwnProperty shorthand */
/******/ 	!function() {
/******/ 		__webpack_require__.o = function(obj, prop) { return Object.prototype.hasOwnProperty.call(obj, prop); }
/******/ 	}();
/******/ 	
/************************************************************************/
var __webpack_exports__ = {};

// EXPORTS
__webpack_require__.d(__webpack_exports__, {
  "default": function() { return /* binding */ src; }
});

;// CONCATENATED MODULE: ./src/utils/getImageColor.js
/**
 * @desc 获取图片主题色
 * @param { url } 图片地址
 */
const getImageColor = function (url) {
  const imgEl = new Image();
  imgEl.crossOrigin = 'anonymous';
  imgEl.src = url;
  return new Promise(function (resolve, reject) {
    imgEl.onload = function () {
      let canvas = document.createElement('canvas'),
          context = canvas.getContext && canvas.getContext('2d'),
          height,
          width,
          length,
          data,
          i = -4,
          blockSize = 5,
          count = 0,
          rgb = {
        r: 0,
        g: 0,
        b: 0
      };
      height = canvas.height = imgEl.height;
      width = canvas.width = imgEl.width;
      context.drawImage(imgEl, 0, 0);
      data = context.getImageData(0, 0, width, height).data;
      length = data.length;

      while ((i += blockSize * 4) < length) {
        ++count;
        rgb.r += data[i];
        rgb.g += data[i + 1];
        rgb.b += data[i + 2];
      }

      rgb.r = ~~(rgb.r / count);
      rgb.g = ~~(rgb.g / count);
      rgb.b = ~~(rgb.b / count);
      resolve(rgb);
    };

    imgEl.onerror = function (e) {
      reject(e);
    };
  });
};

/* harmony default export */ var utils_getImageColor = (getImageColor);
;// CONCATENATED MODULE: ./src/utils/compress.js
/**
 * @desc 压缩图片尺寸
 * @param { src } 图片地址
 * @param { ratio } 缩小比例 scale > 0 && scale <=1
 */
function compress(src, scale) {
  let img;

  if (src.startsWith('http')) {
    img = new Image();
    img.crossOrigin = 'anonymous';
  } else {
    img = document.createElement('img');
  }

  img.src = src;
  return new Promise(function (resolve, reject) {
    img.onload = function () {
      let canvas = document.createElement('canvas'),
          context = canvas.getContext && canvas.getContext('2d'),
          width = canvas.width = img.width * scale,
          height = canvas.height = img.height * scale;
      context.drawImage(img, 0, 0, width, height);
      const base64 = canvas.toDataURL("image/jpeg", 0.92);
      resolve(base64);
    };

    img.onerror = function (e) {
      reject(e);
    };
  });
}

/* harmony default export */ var utils_compress = (compress);
;// CONCATENATED MODULE: ./src/index.js


/* harmony default export */ var src = ({
  getImageColor: utils_getImageColor,
  compress: utils_compress
});
__webpack_exports__ = __webpack_exports__["default"];
/******/ 	return __webpack_exports__;
/******/ })()
;
});