/**
 * @desc 压缩图片尺寸
 * @param { src } 图片地址
 * @param { ratio } 缩小比例 scale > 0 && scale <=1
 */
function compress(src, scale) {
  let img
  if (src.startsWith('http')) {
    img = new Image()
    img.crossOrigin = 'anonymous'
  } else {
    img = document.createElement('img')
  }
  img.src = src
  return new Promise((resolve, reject) => {
    img.onload = () => {
      let canvas = document.createElement('canvas'),
        context = canvas.getContext && canvas.getContext('2d'),
        width = canvas.width = img.width * scale,
        height = canvas.height = img.height * scale

      context.drawImage(img, 0, 0, width, height)
      const base64 = canvas.toDataURL("image/jpeg", 0.92)

      resolve(base64)

    }

    img.onerror = (e) => {
      reject(e)
    }
  })

}

export default compress